Struct
QmiMessageNasAttachDetachOutput
since: 1.20
Description [src]
struct QmiMessageNasAttachDetachOutput {
/* No available fields */
}
The QmiMessageNasAttachDetachOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.20
Instance methods
qmi_message_nas_attach_detach_output_ref
Atomically increments the reference count of self by one.
since: 1.20
qmi_message_nas_attach_detach_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.20